# -*- coding: utf-8 -*-

"""Assemble a BEL graph as bipartite graph of nodes and reified edges."""

from .assembler import *  # noqa: F401,F403
